==> bambu_2.0.4.tar.gz: bambu/tests/testthat/test_txRange.R <==
context("txRange, full length transcript prediction")

test_that("txRange generates a gene and transcript score",{
  se <- readRDS(system.file("extdata", "test_se.rds", 
    package = "bambu"))
  genomeSequence <- readRDS(system.file("extdata", 
    "test_genomeSequence.rds", package = "bambu"))
  annotations <- readRDS(system.file("extdata", 
                                     "test_annotations.rds", package = "bambu"))
  se = scoreReadClasses(se, genomeSequence, annotations, defaultModels)
  
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
                                   package = "bambu"))
  
  expect_is(rowData(se)$txScore, class = 'numeric')
  expect_equal(rowData(se)$txScore, rowData(seExpected)$txScore)
})


test_that("calculateGeneProportion()",{
  se <- readRDS(system.file("extdata", "test_se.rds", package = "bambu"))
  annotations <- readRDS(system.file("extdata", "test_annotations.rds", 
    package = "bambu"))
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
    package = "bambu"))
  rowData(se)$GENEID = assignGeneIds(rowRanges(se), annotations)
  countsTBL = calculateGeneProportion(counts=mcols(se)$readCount,
                                      geneIds=mcols(se)$GENEID)
  expect_equal(countsTBL$geneReadProp, 
               rowData(seExpected)$geneReadProp)
})

test_that("isReadClassCompatible() classifies RCs correctly",{
  se <- readRDS(system.file("extdata", "test_se.rds", package = "bambu"))
  annotations <- readRDS(system.file("extdata", "test_annotations.rds", 
                                     package = "bambu"))
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
                                   package = "bambu"))
  thresholdIndex = which(rowData(se)$readCount>=2)
  compTable = isReadClassCompatible(rowRanges(se[thresholdIndex,]), annotations)
  newRowData = data.frame(equal = compTable$equal,
                          compatible = compTable$compatible)
  rowData(se)[names(newRowData)] = NA
  rowData(se)[thresholdIndex,names(newRowData)] = newRowData
  expect_equal(rowData(se)$equal,rowData(seExpected)$equal)
  expect_equal(rowData(se)$compatible, rowData(seExpected)$compatible)
})

test_that("countPolyATerminals",{
  se <- readRDS(system.file("extdata", "test_se.rds", package = "bambu"))
  genomeSequence <- readRDS(system.file("extdata", "test_genomeSequence.rds", 
                                        package = "bambu"))
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
                                   package = "bambu"))
  thresholdIndex = which(rowData(se)$readCount>=2)
  polyATerminals = countPolyATerminals(rowRanges(se[thresholdIndex,]), genomeSequence)
  newRowData = data.frame(numAstart = polyATerminals$numAstart,
                          numAend = polyATerminals$numAend,
                          numTstart = polyATerminals$numTstart,
                          numTend = polyATerminals$numTend)
  rowData(se)[names(newRowData)] = NA
  rowData(se)[thresholdIndex,names(newRowData)] = newRowData
  
  expect_equal(rowData(se)$numAstart,rowData(seExpected)$numAstart)
  expect_equal(rowData(se)$numAend,rowData(seExpected)$numAend)
  expect_equal(rowData(se)$numTstart,rowData(seExpected)$numTstart)
  expect_equal(rowData(se)$numTend,rowData(seExpected)$numTend)
})

test_that("getTranscriptScore() calculates the correct score", {
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
                                   package = "bambu"))
  se=seExpected
  thresholdIndex = which(rowData(se)$readCount >= 2)
  txScore = getTranscriptScore(rowData(se)[thresholdIndex,], 
                               defaultModels, fit=TRUE)
  rowData(se)$txScore = rep(NA,nrow(se))
  rowData(se)$txScore[thresholdIndex] = txScore
  expect_equal(rowData(se)$txScore, rowData(seExpected)$txScore)
})

test_that("prepareTranscriptModelFeatures() produces the correct data types",{
  #TODO make a expected features dataset to compare to
  se <- readRDS(system.file("extdata", "test_se_scored.rds", package = "bambu"))
  features <- prepareTranscriptModelFeatures(rowData(se))
  expect_is(features$numReads, class = 'numeric')
  expect_is(features$geneReadProp, class = 'numeric')
  expect_is(features$startSD, class = 'numeric')
  expect_is(features$endSD, class = 'numeric')
  expect_is(features$numAstart, class = 'integer')
  expect_is(features$numAend, class = 'integer')
  expect_is(features$numTstart, class = 'integer')
  expect_is(features$numTend, class = 'integer')
  expect_is(features$tx_strand_bias, class = 'numeric')
})

test_that("checkFeatures() detects insufficient samples",{
  se <- readRDS(system.file("extdata", "test_se_scored.rds", package = "bambu"))
  thresholdIndex = which(rowData(se)$readCount>=2)
  features <- prepareTranscriptModelFeatures(rowData(se)[thresholdIndex,])
  trainable = checkFeatures(features)
  #normal se
  expect_equal(trainable, FALSE)
  #TODO se has all TRUE labels
  expect_equal(trainable, FALSE)
  #TODOse with no TRUE labels
  expect_equal(trainable, FALSE)
  #TODO se with not enough points
  expect_equal(trainable, FALSE)
  #TODO se with not enough true/false labels
  expect_equal(trainable, FALSE)
})

==> bambu_2.2.0.tar.gz: bambu/tests/testthat/test_txRange.R <==
context("txRange, full length transcript prediction")

test_that("txRange generates a gene and transcript score",{
  se <- readRDS(system.file("extdata", "test_se.rds", 
    package = "bambu"))
  genomeSequence <- readRDS(system.file("extdata", 
    "test_genomeSequence.rds", package = "bambu"))
  annotations <- readRDS(system.file("extdata", 
                                     "test_annotations.rds", package = "bambu"))
  se = scoreReadClasses(se, genomeSequence, annotations, defaultModels)
  
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
                                   package = "bambu"))
  
  expect_is(rowData(se)$txScore, class = 'numeric')
  expect_equal(rowData(se)$txScore, rowData(seExpected)$txScore)
})


test_that("calculateGeneProportion()",{
  se <- readRDS(system.file("extdata", "test_se.rds", package = "bambu"))
  annotations <- readRDS(system.file("extdata", "test_annotations.rds", 
    package = "bambu"))
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
    package = "bambu"))
  geneIds = assignGeneIds(rowRanges(se), annotations)
  rowData(se)[,names(geneIds)] = geneIds
  countsTBL = calculateGeneProportion(counts=mcols(se)$readCount,
                                      geneIds=mcols(se)$GENEID)
  expect_equal(countsTBL$geneReadProp, 
               rowData(seExpected)$geneReadProp)
})

test_that("isReadClassCompatible() classifies RCs correctly",{
  se <- readRDS(system.file("extdata", "test_se.rds", package = "bambu"))
  annotations <- readRDS(system.file("extdata", "test_annotations.rds", 
                                     package = "bambu"))
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
                                   package = "bambu"))
  thresholdIndex = which(rowData(se)$readCount>=2)
  compTable = isReadClassCompatible(rowRanges(se[thresholdIndex,]), annotations)
  newRowData = data.frame(equal = compTable$equal,
                          compatible = compTable$compatible)
  rowData(se)[names(newRowData)] = NA
  rowData(se)[thresholdIndex,names(newRowData)] = newRowData
  expect_equal(rowData(se)$equal,rowData(seExpected)$equal)
  expect_equal(rowData(se)$compatible, rowData(seExpected)$compatible)
})

test_that("countPolyATerminals",{
  se <- readRDS(system.file("extdata", "test_se.rds", package = "bambu"))
  genomeSequence <- readRDS(system.file("extdata", "test_genomeSequence.rds", 
                                        package = "bambu"))
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
                                   package = "bambu"))
  thresholdIndex = which(rowData(se)$readCount>=2)
  polyATerminals = countPolyATerminals(rowRanges(se[thresholdIndex,]), genomeSequence)
  newRowData = data.frame(numAstart = polyATerminals$numAstart,
                          numAend = polyATerminals$numAend,
                          numTstart = polyATerminals$numTstart,
                          numTend = polyATerminals$numTend)
  rowData(se)[names(newRowData)] = NA
  rowData(se)[thresholdIndex,names(newRowData)] = newRowData
  
  expect_equal(rowData(se)$numAstart,rowData(seExpected)$numAstart)
  expect_equal(rowData(se)$numAend,rowData(seExpected)$numAend)
  expect_equal(rowData(se)$numTstart,rowData(seExpected)$numTstart)
  expect_equal(rowData(se)$numTend,rowData(seExpected)$numTend)
})

test_that("getTranscriptScore() calculates the correct score", {
  seExpected = readRDS(system.file("extdata", "test_se_scored.rds", 
                                   package = "bambu"))
  se=seExpected
  thresholdIndex = which(rowData(se)$readCount >= 2)
  txScore = getTranscriptScore(rowData(se)[thresholdIndex,], 
                               defaultModels, fit=TRUE)
  rowData(se)$txScore = rep(NA,nrow(se))
  rowData(se)$txScore[thresholdIndex] = txScore
  expect_equal(rowData(se)$txScore, rowData(seExpected)$txScore)
})

test_that("prepareTranscriptModelFeatures() produces the correct data types",{
  #TODO make a expected features dataset to compare to
  se <- readRDS(system.file("extdata", "test_se_scored.rds", package = "bambu"))
  features <- prepareTranscriptModelFeatures(rowData(se))
  expect_is(features$numReads, class = 'numeric')
  expect_is(features$geneReadProp, class = 'numeric')
  expect_is(features$startSD, class = 'numeric')
  expect_is(features$endSD, class = 'numeric')
  expect_is(features$numAstart, class = 'integer')
  expect_is(features$numAend, class = 'integer')
  expect_is(features$numTstart, class = 'integer')
  expect_is(features$numTend, class = 'integer')
  expect_is(features$tx_strand_bias, class = 'numeric')
})

test_that("checkFeatures() detects insufficient samples",{
  se <- readRDS(system.file("extdata", "test_se_scored.rds", package = "bambu"))
  thresholdIndex = which(rowData(se)$readCount>=2)
  features <- prepareTranscriptModelFeatures(rowData(se)[thresholdIndex,])
  trainable = checkFeatures(features)
  #normal se
  expect_equal(trainable, FALSE)
  #TODO se has all TRUE labels
  expect_equal(trainable, FALSE)
  #TODOse with no TRUE labels
  expect_equal(trainable, FALSE)
  #TODO se with not enough points
  expect_equal(trainable, FALSE)
  #TODO se with not enough true/false labels
  expect_equal(trainable, FALSE)
})
